@@ -270,7 +270,6 @@ class Runtime:
                     force=True,
                 )
 
-    # pylint: disable=too-many-branches
     def install_requirements(
         self, requirement: str, retry: bool = False, offline: bool = False
     ) -> None:
@@ -296,14 +295,13 @@ class Runtime:
 
             if offline:
                 _logger.warning(
-                    "Role installation skipped because `ansible-galaxy role install` command does not support an offline mode."
+                    "Offline mode ignored because `ansible-galaxy role install` command does not support it."
                 )
-            else:
-                _logger.info("Running %s", " ".join(cmd))
-                result = self.exec(cmd, retry=retry)
-                if result.returncode != 0:
-                    _logger.error(result.stdout)
-                    raise AnsibleCommandError(result)
+            _logger.info("Running %s", " ".join(cmd))
+            result = self.exec(cmd, retry=retry)
+            if result.returncode != 0:
+                _logger.error(result.stdout)
+                raise AnsibleCommandError(result)
 
         # Run galaxy collection install works on v2 requirements.yml
         if "collections" in reqs_yaml:
@@ -314,25 +312,22 @@ class Runtime:
                 "install",
                 "-v",
             ]
-            skip = False
             if offline:
                 if self.version_in_range(upper="2.14"):
                     _logger.warning(
-                        "Collection install skipped because ansible versions before 2.14 do not support an offline mode."
+                        "Offline mode ignored because it is not supported by ansible versions before 2.14."
                     )
-                    skip = True
                 else:
                     cmd.append("--offline")
-            if not skip:
-                cmd.extend(["-r", requirement])
-                if self.cache_dir:
-                    cmd.extend(["-p", f"{self.cache_dir}/collections"])
-                _logger.info("Running %s", " ".join(cmd))
-                result = self.exec(cmd, retry=retry)
-                if result.returncode != 0:
-                    _logger.error(result.stdout)
-                    _logger.error(result.stderr)
-                    raise AnsibleCommandError(result)
+            cmd.extend(["-r", requirement])
+            if self.cache_dir:
+                cmd.extend(["-p", f"{self.cache_dir}/collections"])
+            _logger.info("Running %s", " ".join(cmd))
+            result = self.exec(cmd, retry=retry)
+            if result.returncode != 0:
+                _logger.error(result.stdout)
+                _logger.error(result.stderr)
+                raise AnsibleCommandError(result)
 
     def prepare_environment(  # noqa: C901
         self,
