@@ -2,7 +2,7 @@
 from ansible_compat.runtime import Runtime
 
 
-def test_runtime() -> None:
+def test_runtime_example() -> None:
     """Test basic functionality of Runtime class."""
     # instantiate the runtime using isolated mode, so installing new
     # roles/collections do not pollute the default setup.
@@ -14,7 +14,7 @@ def test_runtime() -> None:
     print(runtime.config.collections_path)
 
     # Detect if current project is a collection and install its requirements
-    runtime.prepare_environment()  # will retry 3 times if needed
+    runtime.prepare_environment(install_local=True)  # will retry 3 times if needed
 
     # Install a new collection (will retry 3 times if needed)
     runtime.install_collection("containers.podman")
